@@ -15,12 +15,12 @@ from colr import color
 JOINTIMEOUT = 3
 RECEIVEMQSITZE = 10
 SERIALLEN = 16
-CRYPTOKEYLEN = 16
+CRYPTOKEYLEN = 32
 ACKTIMEOUT = 3
 BUFFERSIZE = 2048
 SOCKETRETRIES = 3
 SOCKETWAITTIME = 1
-KEEPALIVEFREQUENCY = 30
+KEEPALIVETIMEOUT = 25
 RECONNECTTIMEOUT = 5
 
 class DcsConnection:
@@ -55,7 +55,7 @@ class DcsConnection:
             raise ValueError(errmsg)
 
         if cryptoKey != None and len(cryptoKey) == CRYPTOKEYLEN and type(cryptoKey) == str:
-            self.__cryptoKey__ = cryptoKey.encode('utf-8')
+            self.__cryptoKey__ = bytearray.fromhex(cryptoKey)
         else:
             errmsg = "Instance not created. CryptoKey invalid. CryptoKey=" + str(cryptoKey)
             logging.error(errmsg)
@@ -90,7 +90,7 @@ class DcsConnection:
     def getServer(self):
         return self.__serverAddress__
 
-    def getSocketHash(self):
+    def getsockethash(self):
         return self.__socket__.__hash__()
 
     def addDevice(self, device):
@@ -100,7 +100,7 @@ class DcsConnection:
         else:
             return False
 
-    def isConnected(self):
+    def isconnected(self):
         return self.__connected__
 
     def connect(self):
@@ -114,6 +114,8 @@ class DcsConnection:
         else:
             logging.debug(str(id(self)) + " threads already running")
         result = self.__dcsConnect__()
+        if not result:
+            logging.warning(str(id(self)) + " Failed to connect " + str(self.__serial__ ) + "@" + str(self.__serverAddress__) + ":" + str(self.__serverPort__) + ". Check encryption key!")
         self.__keepConnected__ = True
         return result
 
@@ -217,75 +219,75 @@ class DcsConnection:
             message = None         
             try:
                 message = self.__receivedMessageQueue__.get_nowait()
-            except:
+            except Exception:
                 pass
 
             if(message):
                 logging.debug(str(id(self)) + " Handling Message: " + str(message))
                 try:
-                    self.__handleMessage__(message["type"], message["payload"], message["tid"])
+                    self.__handlemessage__(message["type"], message["payload"], message["tid"])
                 except Exception as e:
                     logging.error(str(id(self)) + " Error handling message. " + str(e))
 
-    def __handleMessage__(self, msgType, payload, tid):
-        if(msgType == 9):
+    def __handlemessage__(self, msgtype, payload, tid):
+        if(msgtype == 9):
             logging.debug(str(id(self)) + " TID: " + str(tid) + "; Received ACK")
             try:
-                self.__ackRequest__(tid)    #just notify waiting messages and do nothing more
+                self.__ackrequest__(tid)    #just notify waiting messages and do nothing more
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error handling ACK")
             return
 
-        if(msgType == 8):
+        if(msgtype == 8):
             logging.debug(str(id(self)) + " TID: " + str(tid) + "; Received Keep Alive.")
             try:
-                self.__send__(None, 9, tid, isResponce=True)     #send ACK
+                self.__send__(None, 9, tid, isresponce=True)     #send ACK
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error sending ACK")
             return
 
-        if(msgType == 4):
+        if(msgtype == 4):
             logging.info(str(id(self)) + " TID: " + str(tid) + "; Received Curent Data Request.")
             try:
-                self.sendData(tid=tid)
+                self.senddata(tid=tid)
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error sending data." +  str(e))
             return
 
-        if(msgType == 5):
+        if(msgtype == 5):
             logging.info(str(id(self)) + " TID: " + str(tid) + "; Received Setup Change.")
             try:
                 self.__changeSetup__(payload)
             except Exception as e:
                 logging.error(str(id(self)) + " Error applying setup changes. " + str(e))
             try:
-                self.sendSetup(tid=tid)
+                self.sendsetup(tid=tid)
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error sending setup response")
             return
 
-        if(msgType == 6):
+        if(msgtype == 6):
             logging.info(str(id(self)) + " TID: " + str(tid) + "; Calc Log Daten (für MSG.Type 2).")
             try:
-                self.loadLogData()
+                self.loadlogdata()
             except Exception as e:
                 logging.warning(str(id(self)) + " TID: " + str(tid) + "; Error getting logData")
             try:
-                self.__send__(None, 9, tid, isResponce=True)     #send ACK
-                self.clearLogData()
+                self.__send__(None, 9, tid, isresponce=True)     #send ACK
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error sending ACK for Calc Log Data")
+            self.clearlogdata()
             return
 
-        if(msgType == 7):
+        if(msgtype == 7):
             logging.info(str(id(self)) + " TID: " + str(tid) + "; Send Log Daten (MSG.Type 2).")
             try:
-                self.sendLogData(tid=tid)
+                self.sendlogdata(tid=tid)
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + "; Error sending logData.")
             return
 
-        logging.info(str(id(self)) + " TID: " + str(tid) + "; Unknown MSG-Type received: " + str(msgType) + ".")
+        logging.info(str(id(self)) + " TID: " + str(tid) + "; Unknown MSG-Type received: " + str(msgtype) + ".")
     
     def watchdog(self):
         logging.debug(str(id(self)) + " Watchdog running...")
@@ -313,15 +315,15 @@ class DcsConnection:
         
         if(self.__lastMessageTime__ != None):
             difference = datetime.now() - self.__lastMessageTime__
-            if(difference.total_seconds() > KEEPALIVEFREQUENCY):
-                logging.error(str(id(self)) + " No message received for more then " + str(KEEPALIVEFREQUENCY) + " secunds. Reconnecting...")
+            if(difference.total_seconds() > KEEPALIVETIMEOUT):
+                logging.error(str(id(self)) + " No message received for more then " + str(KEEPALIVETIMEOUT) + " secunds. Reconnecting...")
                 try:
                     self.reconnect()
                 except Exception as e:
                     logging.warning(str(id(self)) + "Cannot reconect. " + str(e))
 
         if(self.__keepConnected__ == True and self.__connected__ != True):
-            logging.error(str(id(self)) + " disconnection detected. Reconnecting...")
+            logging.info(str(id(self)) + " disconnection detected. Reconnecting...")
             try:
                 self.reconnect()
             except Exception as e:
@@ -350,7 +352,7 @@ class DcsConnection:
             logging.debug(str(id(self)) + " preparing socket.... ")
             if(self.__checkSocket__()):
                 try:
-                    self.sendSetup(True)
+                    self.sendsetup(True)
                 except Exception as e:
                     logging.error(str(id(self)) + " connection failed. " + str(e))
                     return False
@@ -379,7 +381,7 @@ class DcsConnection:
         host = ""
         try:
             host = socket.gethostbyname(self.__serverAddress__)
-        except:
+        except Exception:
             logging.error(str(id(self)) + " Host not found.")
             self.__socket__ = None
             return False
@@ -389,7 +391,7 @@ class DcsConnection:
                 logging.debug(str(id(self)) + " trying to connect socket " + str(host) + ":" + str(self.__serverPort__) + "...")
                 self.__socket__.connect((host, self.__serverPort__))
                 break
-            except:
+            except Exception:
                 logging.warning(str(id(self)) + " Cannot connect to " + str(host) + ":" + str(self.__serverPort__) + ".")
                 socketRetries = socketRetries + 1
                 time.sleep(SOCKETWAITTIME)
@@ -404,6 +406,12 @@ class DcsConnection:
         return False
 
     def __dcsDisconnect__(self):
+        try:
+            if self.__receivedMessageQueue__ != None:
+                self.__receivedMessageQueue__.queue.clear()
+        except Exception as e:
+            logging.error(str(id(self)) + " cannot clear receivedMessageQueue. " + str(e))
+            return False
         if self.__socket__ == None or self.__socket__._closed:
             logging.info(str(id(self)) + " Socket is already closed")
             return True
@@ -413,14 +421,14 @@ class DcsConnection:
             return True
         except Exception as e:
             logging.error(str(id(self)) + " closing socket failed. " + str(e))
-            return False
+            return False    
 
     def __closeSocket__(self):
         self.__socketLock__.acquire()
         self.__socket__.close()
         self.__socketLock__.release()
 
-    def __ackRequest__(self, tid):
+    def __ackrequest__(self, tid):
         self.__messageLock__.acquire()
         try:
             self.__sentRequests__[tid]["state"] = "ACK"
@@ -434,7 +442,7 @@ class DcsConnection:
             logging.warning(str(id(self)) + " TID: " + str(tid) + " Request not found. Could not wakeup. " + str(e))
         self.__messageLock__.release()
 
-    def __send__(self, payload, msgtype, tid, isResponce=False, nack=False):
+    def __send__(self, payload, msgtype, tid, isresponce=False, nack=False):
         if self.__socket__ == None or self.__socket__._closed:
             errmsg = str(id(self)) + "Cannot send. No open Socket."
             logging.error(errmsg)
@@ -444,7 +452,7 @@ class DcsConnection:
         except Exception as e:
             return False
         if package != None:
-            if self.__registerMessage__(tid, msgtype):
+            if self.__registermessage__(tid, msgtype):
                 try:
                     self.__socketLock__.acquire()
                     self.__socket__.send(package)
@@ -457,7 +465,7 @@ class DcsConnection:
                     self.__socketLock__.release()
                     return False
                 
-                if(isResponce == False):
+                if(isresponce == False):
                     if(not self.__waitForAck__(tid)): 
                         logging.warning(str(id(self)) + " TID: " + str(tid) + "; Type: " + str(msgtype) + " no ACK received.")
                         return False
@@ -469,8 +477,8 @@ class DcsConnection:
             logging.error(str(id(self)) + " no package to send")
             return False
 
-    def __registerMessage__(self, tid, msgType):
-        if msgType == 9:
+    def __registermessage__(self, tid, msgtype):
+        if msgtype == 9:
             return True;
         self.__messageLock__.acquire()
         self.__cleanSentrequests__()
@@ -480,7 +488,7 @@ class DcsConnection:
                 logging.error("[" + self.__serial__ + "] tid " + str(tid) + " already in use")
                 self.__messageLock__.release()
                 return False
-        except:
+        except Exception:
             pass
 
         event = threading.Event()
@@ -535,7 +543,7 @@ class DcsConnection:
             raise Exception(errorMsg)
 
         if(msgtype == None):
-            errorMsg = str(id(self)) + " no MSGTYPE set "
+            errorMsg = str(id(self)) + " no msgtype set "
             logging.warning("TID: " + str(tid) + " MakePackage: " + str(errorMsg))
             raise Exception(errorMsg)
 
@@ -556,6 +564,7 @@ class DcsConnection:
         try:
             rand = self.__get_random_string__(8)
             iv = rand.encode('utf-8')
+            # iv = "50976281".encode('utf-8')     #Todo: woher kommt die Zahl?
         except Exception as e:
             logging.error("TID: " + str(tid) + " Error generating IV: " + str(e))
             raise(e)
@@ -603,19 +612,19 @@ class DcsConnection:
         elements = setup_string.split("&")
         return elements
 
-    def sendData(self, tid=None):
+    def senddata(self, tid=None):
         if(self.__connected__):
             data = self.__getCurrentData__()
             if(tid == None):
-                isResponce=False
+                isresponce=True
                 tid = self.__getTid__()
             else:
-                isResponce=True
+                isresponce=True
                 if(tid > 65535 or tid < 1):
                     raise Exception("TID out of range (1-65535)")
             logging.info(str(id(self)) + " TID: " + str(tid) + ", sending data: " + str(data))
             try:
-                if(not self.__send__(data, 1, tid, isResponce=isResponce)):
+                if(not self.__send__(data, 1, tid, isresponce=isresponce)):
                     raise Exception("Cannot send data. TID: " + str(tid) + ". " + str(data))
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + ", Error: " + str(e))
@@ -625,7 +634,7 @@ class DcsConnection:
             logging.error(errormsg)
             raise Exception(errormsg)
 
-    def sendLogData(self, tid=None):
+    def sendlogdata(self, tid=None):
         logData = self.__logData__
         if(logData == None):
             error = str(id(self)) + " Cannot send logData. Empty Logdata."
@@ -635,14 +644,14 @@ class DcsConnection:
         if(self.__connected__):
             if(tid == None):
                 tid = self.__getTid__()
-                isResponce = False
+                isresponce = True
             else:
-                isResponce = True
+                isresponce = True
                 if(tid > 65535 or tid < 1):
                     raise Exception("TID out of range (1-65535)")
             logging.info(str(id(self)) + " TID: " + str(tid) + ", sending logData: " + str(self.__logData__))
             try:
-                if(not self.__send__(logData, 2, tid, isResponce=isResponce)):
+                if(not self.__send__(logData, 2, tid, isresponce=isresponce)):
                     raise Exception("Error sending logData.")
             except Exception as e:
                 logging.error(str(id(self)) + " TID: " + str(tid) + ", Error: " + str(e))
@@ -665,19 +674,19 @@ class DcsConnection:
         self.__messageLock__.release()
         return found
 
-    def sendSetup(self, forced = None, tid=None):
+    def sendsetup(self, forced = None, tid=None):
         if(self.__connected__ or forced):
-            setup = self.__getSetup__()
+            setup = self.__getsetup__()
             if(tid == None):
                 tid = self.__getTid__()
-                isResponce = False
+                isresponce = False
             else:
-                isResponce = True
+                isresponce = True
                 if(tid > 65535 or tid < 1):
                     raise Exception("TID out of range (1-65535)")
             logging.info(str(id(self)) + " TID: " + str(tid) + ", sending setup: " + str(setup))
             try:
-                if(not self.__send__(setup, 3, tid, isResponce=isResponce)):
+                if(not self.__send__(setup, 3, tid, isresponce=isresponce)):
                     raise Exception("Error sending setup.")
             except Exception as e:
                 logging.error("TID: " + str(tid) + ", Error: " + str(e)) 
@@ -687,12 +696,12 @@ class DcsConnection:
             logging.error(errormsg)
             raise Exception(errormsg)
 
-    def __getSetup__(self):
+    def __getsetup__(self):
         if(self.__device__ == None):
             logging.warning(str(id(self)) + " device not found. sending dummy setup")
             return {"device": "ConnectionTest", "fwversion": "1.0.0", "serialno": self.__serial__ }
         else:
-            return self.__device__.getSetup()
+            return self.__device__.getsetup()
 
     def __getCurrentData__(self):
         if(self.__device__ == None):
@@ -700,21 +709,24 @@ class DcsConnection:
             t = datetime.now()
             return {"power": t.second * 100}
         else:
-            return self.__device__.getData()
+            return self.__device__.getdata()
     
-    def loadLogData(self):
+    def loadlogdata(self):
         if(self.__device__ == None):
             logging.warning(str(id(self)) + " device not found. getting dummy logData")
             t = datetime.now()
             self.__logData__ = {"i_power": t.second * 100}
         else:
-            self.__logData__ = self.__device__.getLogData()
+            self.__logData__ = self.__device__.getlogdata()
 
-    def clearLogData(self):
+    def clearlogdata(self):
         if(self.__device__ == None):
             logging.warning(str(id(self)) + " device not found. nothing to clean.")
         else:
-            self.__device__.clearLog()
+            try:
+                self.__device__.clearlog()
+            except Exception as e:
+                logging.warning(str(id(self)) + " cannot clean logdata.")
 
     def __changeSetup__(self, payload):
         try:
@@ -736,7 +748,7 @@ class DcsConnection:
                     logging.warning(str(id(self)) + " device not found. Settings not applied.")
                     print("Field:" + str(field) + "; Value=" + str(value))
                 else:
-                    self.__device__.setSetupValue(field, value)        					
+                    self.__device__.setsetupvalue(field, value)        					
 
 # Entry Point     
 if __name__ == "__main__":
@@ -746,8 +758,8 @@ if __name__ == "__main__":
     serial = "120100200505tes1"
     serial2 = "120100200505tes2"
     serial3 = "120100200505tes3"
-    cryptoKey = "ABABABABABABABAB"
-    cryptoKeyInvalid = "ABABABABABABAB00"
+    cryptoKey = "41424142414241424142414241424142"
+    cryptoKeyInvalid = "ABABABABABABAB00ABABABABABABAB00"
     server = "my-pv.live"
 
     #AUTO-Tests
@@ -854,13 +866,13 @@ if __name__ == "__main__":
     connection.disconnect()
 
     #connecting with invalid cryptoKey
-    connection = DcsConnection(serial, "1111111111111111", server, 50333)
+    connection = DcsConnection(serial, "1"*CRYPTOKEYLEN, server, 50333)
     if(connection.connect()):
         print(color('ERROR: Connection with an invalid crypto key esteblished.', fore='red', style='bright'))
     else:
         print(color('SUCCESS: Connection with an invalid crypto key failed.', fore='green', style='bright'))
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('ERROR: sending data with invalid encryption Key.', fore='red', style='bright'))
     except Exception as e:
         print(color('ERROR: sending data with invalid encryption Key.', fore='green', style='bright'))
@@ -873,7 +885,7 @@ if __name__ == "__main__":
     else:
         print(color('SUCCESS: Connection using an unknown serial failed.', fore='green', style='bright'))
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('ERROR: sending data with unknown device.', fore='red', style='bright'))
     except Exception as e:
         print(color('SUCCESS: sending data with unknown device.', fore='green', style='bright'))
@@ -897,10 +909,10 @@ if __name__ == "__main__":
     state = connection.connect()
     #connection with invalid key but same serial
     connection2 = DcsConnection(serial, cryptoKeyInvalid, server, 50333) 
-    state2 = connection.connect()
+    state2 = connection2.connect()
     #send data using first valid connection
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('SUCCESS: sending using valid connection after trying to connect with an invalid connection.', fore='green', style='bright'))
     except Exception as e:
         print(color('ERROR: sending using valid connection after trying to connect with an invalid connection.', fore='red', style='bright'))
@@ -911,21 +923,21 @@ if __name__ == "__main__":
     #send without beeing connected
     connection = DcsConnection(serial, cryptoKey, server, 50333)
     try:
-        connection.sendSetup()
+        connection.sendsetup()
         print(color('ERROR: sending setup without beeing connected.', fore='red', style='bright'))
     except Exception as e:
         print(color('SUCCESS: sending setup without beeing connected.', fore='green', style='bright'))
 
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('ERROR: sending data without beeing connected.', fore='red', style='bright'))
     except Exception as e:
         print(color('SUCCESS: sending data without beeing connected.', fore='green', style='bright'))
 
     try:
-        connection.loadLogData()
-        connection.clearLogData()
-        connection.sendLogData()
+        connection.loadlogdata()
+        connection.clearlogdata()
+        connection.sendlogdata()
         print(color('ERROR: sending logData without beeing connected.', fore='red', style='bright'))
     except Exception as e:
         print(color('SUCCESS: sending logData without beeing connected.', fore='green', style='bright'))
@@ -936,21 +948,21 @@ if __name__ == "__main__":
         print(color('ERROR: Cannot connect for connection tests.', fore='red', style='bright'))
 
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('SUCCESS: sending data.', fore='green', style='bright'))
     except Exception as e:
         print(color('ERROR: sending data.', fore='red', style='bright'))
 
     try:
-        connection.loadLogData()
-        connection.clearLogData()
-        connection.sendLogData()
+        connection.loadlogdata()
+        connection.clearlogdata()
+        connection.sendlogdata()
         print(color('SUCCESS: sending logData.', fore='green', style='bright'))
     except Exception as e:
         print(color('ERROR: sending logData.', fore='red', style='bright'))
 
     try:
-        connection.sendSetup()
+        connection.sendsetup()
         print(color('SUCCESS: sending setup.', fore='green', style='bright'))
     except Exception as e:
         print(color('ERROR: sending setup.', fore='red', style='bright'))
@@ -961,7 +973,7 @@ if __name__ == "__main__":
     connection = DcsConnection(serial, cryptoKey, server, 50333)
     connection.connect()
     try:
-        connection.sendLogData()
+        connection.sendlogdata()
         print(color('ERROR: sending empty logData.', fore='red', style='bright'))
     except:
         print(color('SUCCESS: sending empty logData.', fore='green', style='bright'))
@@ -970,33 +982,33 @@ if __name__ == "__main__":
     ##active/passive clients tests
     connection = DcsConnection(serial, cryptoKey, server, 50333)
     connection.connect()
-    socketHash = connection.getSocketHash()
-    time.sleep(15 + KEEPALIVEFREQUENCY)
-    if(connection.isConnected() and socketHash == connection.getSocketHash()):
-        print(color('SUCCESS: Check isConnected.', fore='green', style='bright'))
+    socketHash = connection.getsockethash()
+    time.sleep(15 + KEEPALIVETIMEOUT)
+    if(connection.isconnected() and socketHash == connection.getsockethash()):
+        print(color('SUCCESS: Check isconnected.', fore='green', style='bright'))
     else:
-        print(color('ERROR: Check isConnected.', fore='red', style='bright'))
+        print(color('ERROR: Check isconnected.', fore='red', style='bright'))
 
     #switch to active client by sending data
     try:
-        connection.loadLogData()
-        connection.clearLogData()
-        connection.sendLogData()
+        connection.loadlogdata()
+        connection.clearlogdata()
+        connection.sendlogdata()
         print(color('SUCCESS: sending unexpected logData after waiting.', fore='green', style='bright'))
     except:
         print(color('ERROR: sending unexpected logData after waiting.', fore='red', style='bright'))
     #switch to active client by sending data   
     try:
-        connection.sendData()
+        connection.senddata()
         print(color('SUCCESS: sending unexpected currData after waiting.', fore='green', style='bright'))
     except:
         print(color('ERROR: sending unexpected currData after waiting.', fore='red', style='bright'))
     
-    time.sleep(10 + KEEPALIVEFREQUENCY)
-    if(connection.isConnected() and socketHash == connection.getSocketHash()):
+    time.sleep(10 + KEEPALIVETIMEOUT)
+    if(connection.isconnected() and socketHash == connection.getsockethash()):
         print(color('SUCCESS: Check if socket has changed.', fore='green', style='bright'))
     else:
-        print(color('ERROR: Check if socket has changed. Old socket-Hash: ' + str(socketHash) + ', new socket-Hash: ' + str(connection.getSocketHash()), fore='red', style='bright'))
+        print(color('ERROR: Check if socket has changed. Old socket-Hash: ' + str(socketHash) + ', new socket-Hash: ' + str(connection.getsockethash()), fore='red', style='bright'))
     connection.disconnect()
 
     ## watchdog tests
@@ -1022,24 +1034,24 @@ if __name__ == "__main__":
     connection.connect()
     connection2.connect()
     connection3.connect()
-    hash1 = connection.getSocketHash()
-    hash2 = connection2.getSocketHash()
-    hash3 = connection3.getSocketHash()
+    hash1 = connection.getsockethash()
+    hash2 = connection2.getsockethash()
+    hash3 = connection3.getsockethash()
     try:
         while True:
             print(color('[DCS-Connection] Communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             connection.watchdog()
             connection2.watchdog()
             connection3.watchdog()
-            if(hash1 != connection.getSocketHash()):
+            if(hash1 != connection.getsockethash()):
                 print(color('[DCS-Connection] Socket of serial ' + str(serial) + ' has changed.', fore='red', style='bright'))
-                hash1 = connection.getSocketHash()
-            if(hash2 != connection2.getSocketHash()):
+                hash1 = connection.getsockethash()
+            if(hash2 != connection2.getsockethash()):
                 print(color('[DCS-Connection] Socket of serial ' + str(serial2) + ' has changed.', fore='red', style='bright'))
-                hash2 = connection2.getSocketHash()
-            if(hash3 != connection3.getSocketHash()):
+                hash2 = connection2.getsockethash()
+            if(hash3 != connection3.getsockethash()):
                 print(color('[DCS-Connection] Socket of serial ' + str(serial3) + ' has changed.', fore='red', style='bright'))
-                hash3 = connection3.getSocketHash()
+                hash3 = connection3.getsockethash()
             time.sleep(10)
     except KeyboardInterrupt as e:
         print("[DCS-Connection] Stopping Test...")
