@@ -6,27 +6,30 @@ import logging
 import time
 import json
 
-from mypvdevices.Device import Device
+import sys
+import os
+
+PACKAGE_PARENT = '..'
+SCRIPT_DIR = os.path.dirname(os.path.realpath(os.path.join(os.getcwd(), os.path.expanduser(__file__))))
+sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
+
+from mypvdevices.ModbusRtuDevice import ModbusRtuDevice
 from mypvdevices.ModbusConnection import ModbusConnection
 
 MODBUSWARNLEVEL = 0.5
 REGISTERTIMEOUT = 5
 BUILDNR = "4321"
 
-class DeviceDcElwa(Device):
+class DeviceDcElwa(ModbusRtuDevice):
     __firmwareVersion__ = "1." + str(BUILDNR)
-    __deviceType__ = "ELWA"
+    __devicetype__ = "ELWA"
 
-    def __init__(self, serial, nodeId):
-        self.__nodeId__ = nodeId
-        Device.__init__(self, serial)
+    def __init__(self, serial, nodeid):
+        ModbusRtuDevice.__init__(self, serial, nodeid)
 
-    def getIdentifier(self):
-        return self.getSerial() + ", Node: " + str(self.__nodeId__)
-
-    def __createSetup__(self):
+    def __createsetup__(self):
         return {
-            "device": self.__deviceType__, \
+            "device": self.__devicetype__, \
             "fwversion": self.__firmwareVersion__, \
             "serialno": self.__serial__, \
             "elno": self.__nodeId__, \
@@ -34,7 +37,7 @@ class DeviceDcElwa(Device):
             "ww2offset": 1514
             }
 
-    def __getSettingsMap__(self):
+    def __getsettingsmap__(self):
         settings = {
             "ww2target": {
                 "register": 1022,   #ELWA Modbus Interface boost temperature
@@ -47,11 +50,11 @@ class DeviceDcElwa(Device):
         }
         return settings
 
-    def getData(self):
+    def getdata(self):
 
-        acRelayState = self.getDataset("ac_relay_state")
-        dcPower = self.getDataset("dc_power")
-        operationMode = self.getDataset("operation_mode")
+        acRelayState = self.getdataset("ac_relay_state")
+        dcPower = self.getdataset("dc_power")
+        operationMode = self.getdataset("operation_mode")
 
         if operationMode == 3 or operationMode == 5 or operationMode == 6 or operationMode == 7 or operationMode == 8 or operationMode == 9 or operationMode == 10 or operationMode == 11 or operationMode == 12 or operationMode == 13 or operationMode == 14 or operationMode == 15 or operationMode == 16 or operationMode == 20 or operationMode == 21 or operationMode == 135:
             acHeating = True
@@ -74,50 +77,49 @@ class DeviceDcElwa(Device):
             meter = None
 
         data={
-            "device": self.__deviceType__,
+            "device": self.__devicetype__,
             "fwversion": self.__firmwareVersion__,
             "loctime": time.strftime("%H:%M:%S"),
             "dev_id": self.__nodeId__,
-            "day_counter" : self.getDataset("day_counter"),
+            "day_counter" : self.getdataset("day_counter"),
             "op_mode": operationMode,
-            "dc_breaker": self.getDataset("dc_breaker_state"),
-            "dc_relay": self.getDataset("dc_relay_state"),
+            "dc_breaker": self.getdataset("dc_breaker_state"),
+            "dc_relay": self.getdataset("dc_relay_state"),
             "ac_relay": acRelayState,
-            "temp1": self.getDataset("temp1"),
-            "temp_day_min": self.getDataset("temp_day_min"),
-            "temp_day_max": self.getDataset("temp_day_max"),
-            "ww1target": self.getDataset("dc_temp_target"),
-            "ac_temp_target": self.getDataset("ac_temp_target"),
-            "tempchip": self.getDataset("tempchip"),
-            "iso_voltage": self.getDataset("iso_voltage"),
-            "dc_voltage": self.getDataset("dc_voltage"),
-            "dc_current": self.getDataset("dc_current"),
+            "temp1": self.getdataset("temp1"),
+            "temp_day_min": self.getdataset("temp_day_min"),
+            "temp_day_max": self.getdataset("temp_day_max"),
+            "ww1target": self.getdataset("dc_temp_target"),
+            "ac_temp_target": self.getdataset("ac_temp_target"),
+            "tempchip": self.getdataset("tempchip"),
+            "iso_voltage": self.getdataset("iso_voltage"),
+            "dc_voltage": self.getdataset("dc_voltage"),
+            "dc_current": self.getdataset("dc_current"),
             "power_elwa": power,
             "boostpower_elwa": boostpower,
-            "dc_day_wh": self.getDataset("dc_day_wh"),
-            "dc_total_kwh": self.getDataset("dc_total_kwh"),
-            "ac_day_wh": self.getDataset("ac_day_wh"),
-            "minutes_from_noon": self.getDataset("minutes_from_noon"),
-            "minutes_since_dusk": self.getDataset("minutes_since_dusk"),
-            "ac_boost_mode": self.getDataset("ac_boost_mode"),
+            "dc_day_wh": self.getdataset("dc_day_wh"),
+            "dc_total_kwh": self.getdataset("dc_total_kwh"),
+            "ac_day_wh": self.getdataset("ac_day_wh"),
+            "minutes_from_noon": self.getdataset("minutes_from_noon"),
+            "minutes_since_dusk": self.getdataset("minutes_since_dusk"),
+            "ac_boost_mode": self.getdataset("ac_boost_mode"),
             "m1sum": dcPower,
             "m0sum": meter,
-            "temp2": self.getDataset("temp2"),
-            "ww2target": self.getDataset("boost_temp_target"),
-            "ww2offset": self.getDataset("ww2offset_calibration"),
-            "modbuserrorrate":  self.getCommunicationErrorsRate()
+            "temp2": self.getdataset("temp2"),
+            "ww2target": self.getdataset("boost_temp_target"),
+            "ww2offset": self.getdataset("ww2offset_calibration"),
+            "modbuserrorrate":  self.getcommunicationerrorsrate()
             }            
         return data
 
-    def getLogData(self):
-
-        acRelayState = self.getLogValue("ac_relay_state")
+    def getlogdata(self):
+        acRelayState = self.getlogvalue("ac_relay_state")
         if acRelayState != None:
             boostpower = int(round(acRelayState*750))
         else:
             boostpower = None
         
-        dcPower = self.getIntLogValue("dc_power")
+        dcPower = self.getintlogvalue("dc_power")
         if dcPower != None:
             if(boostpower != None):
                 power = int(dcPower + boostpower)
@@ -133,31 +135,31 @@ class DeviceDcElwa(Device):
         pvprod = dcPower
 
         sLog={
-			"modbus_error_rate" : self.getCommunicationErrorsRate(),
-			"day_counter" : self.getIntLogValue("day_counter"),
-			"op_mode": self.getIntLogValue("operation_mode"),
-			"dc_breaker": self.getIntLogValue("dc_breaker_state"),
-			"dc_relay": self.getIntLogValue("dc_relay_state"),
-			"ac_relay": self.getIntLogValue("ac_relay_state"),
-			"temp": self.getIntLogValue("temp1"),
-			"temp_day_min": self.getIntLogValue("temp_day_min"),
-			"temp_day_max": self.getIntLogValue("temp_day_max"),
-			"dc_temp_target": self.getIntLogValue("dc_temp_target"),
-			"ac_temp_target": self.getIntLogValue("ac_temp_target"),
-			"temp_internal": self.getIntLogValue("tempchip"),
-			"iso_voltage": self.getIntLogValue("iso_voltage"),
-			"dc_voltage": self.getIntLogValue("dc_voltage"),
-			"dc_current": self.getIntLogValue("dc_current"),
-			"dc_power": self.getIntLogValue("dc_power"),
-			"dc_day_wh": self.getIntLogValue("dc_day_wh"),
-			"dc_total_kwh": self.getIntLogValue("dc_total_kwh"),
-			"ac_day_wh": self.getIntLogValue("ac_day_wh"),
-			"minutes_from_noon": self.getIntLogValue("minutes_from_noon"),
-			"minutes_since_dusk": self.getIntLogValue("minutes_since_dusk"),
-			"ac_boost_mode": self.getIntLogValue("ac_boost_mode"),
-			"temp2": self.getIntLogValue("temp2"),
-			"ww2target": self.getIntLogValue("boost_temp_target"),
-			"ww2offset": self.getIntLogValue("ww2offset_calibration"),
+			"modbus_error_rate" : self.getcommunicationerrorsrate(),
+			"day_counter" : self.getintlogvalue("day_counter"),
+			"op_mode": self.getintlogvalue("operation_mode"),
+			"dc_breaker": self.getintlogvalue("dc_breaker_state"),
+			"dc_relay": self.getintlogvalue("dc_relay_state"),
+			"ac_relay": self.getintlogvalue("ac_relay_state"),
+			"temp": self.getintlogvalue("temp1"),
+			"temp_day_min": self.getintlogvalue("temp_day_min"),
+			"temp_day_max": self.getintlogvalue("temp_day_max"),
+			"dc_temp_target": self.getintlogvalue("dc_temp_target"),
+			"ac_temp_target": self.getintlogvalue("ac_temp_target"),
+			"temp_internal": self.getintlogvalue("tempchip"),
+			"iso_voltage": self.getintlogvalue("iso_voltage"),
+			"dc_voltage": self.getintlogvalue("dc_voltage"),
+			"dc_current": self.getintlogvalue("dc_current"),
+			"dc_power": self.getintlogvalue("dc_power"),
+			"dc_day_wh": self.getintlogvalue("dc_day_wh"),
+			"dc_total_kwh": self.getintlogvalue("dc_total_kwh"),
+			"ac_day_wh": self.getintlogvalue("ac_day_wh"),
+			"minutes_from_noon": self.getintlogvalue("minutes_from_noon"),
+			"minutes_since_dusk": self.getintlogvalue("minutes_since_dusk"),
+			"ac_boost_mode": self.getintlogvalue("ac_boost_mode"),
+			"temp2": self.getintlogvalue("temp2"),
+			"ww2target": self.getintlogvalue("boost_temp_target"),
+			"ww2offset": self.getintlogvalue("ww2offset_calibration"),
         }
 
         logData = { 
@@ -165,13 +167,13 @@ class DeviceDcElwa(Device):
             "i_boostpower": boostpower,
             "i_m1sum": pvprod,
             "i_metercons": metercons,
-            "i_temp1": self.getIntLogValue("temp1"),
-            "i_temp2": self.getIntLogValue("temp2"),
+            "i_temp1": self.getintlogvalue("temp1"),
+            "i_temp2": self.getintlogvalue("temp2"),
             "s_json" : json.dumps(sLog)
         }
 
         ModbusConnection.instance().resetCounters(self.__nodeId__)
-        self.__logData__.clear()
+        self.__logdata__.clear()
         return logData
 
     def __checkRegiterTimeStamp__(self):
@@ -185,48 +187,48 @@ class DeviceDcElwa(Device):
     
     def __supervise__(self):
         
-        value = self.getDataset("temp1")
+        value = self.getdataset("temp1")
         if value != None and ( value > 1200 or value < 0 ):
-            logging.error("[Device] " + self.getIdentifier() + " - Temp1 sensor error: " + str(value))
+            logging.error("[Device] " + self.getidentifier() + " - Temp1 sensor error: " + str(value))
             temp1error = True
         else:
             temp1error = False
 
-        value = self.getDataset("temp2")
+        value = self.getdataset("temp2")
         if value != None and ( value > 1200 or value < 0 ):
-            logging.error("[Device] " + self.getIdentifier() + " - Temp2 sensor error: " + str(value))
+            logging.error("[Device] " + self.getidentifier() + " - Temp2 sensor error: " + str(value))
             temp2error = True
         else:
             temp2error = False
 
-        value = self.getDataset("tempchip")
+        value = self.getdataset("tempchip")
         if value == 0 :
-            logging.error("[Device] " + self.getIdentifier() + " - No IR Connection to Device.")
+            logging.error("[Device] " + self.getidentifier() + " - No IR Connection to Device.")
             irError = True
         else:
             irError = False
 
-        value = self.getDataset("operation_mode")
+        value = self.getdataset("operation_mode")
         if value != None and value > 100 :
-            logging.error("[Device] " + self.getIdentifier() + " - Operation Mode " + str(value) + " detected.")
+            logging.error("[Device] " + self.getidentifier() + " - Operation Mode " + str(value) + " detected.")
             opmodeError = True
         else:
             opmodeError = False
 
-        modbusErrorRate = self.getCommunicationErrorsRate()
+        modbusErrorRate = self.getcommunicationerrorsrate()
         if modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
-            logging.error("[Device] " + self.getIdentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
+            logging.error("[Device] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
             modbusWarning = True
         else:
             modbusWarning = False
         if modbusErrorRate == 1 :
-            logging.error("[Device] " + self.getIdentifier() + " - Modbus communication to device not working.")
+            logging.error("[Device] " + self.getidentifier() + " - Modbus communication to device not working.")
             modbusError = True
         else:
             modbusError = False
 
         if self.__checkRegiterTimeStamp__() != True:
-            logging.error("[Device] " + self.getIdentifier() + " - Register values to old. Communication errors expected.")
+            logging.error("[Device] " + self.getidentifier() + " - Register values to old. Communication errors expected.")
             registerError = True
         else:
             registerError = False
@@ -241,9 +243,9 @@ class DeviceDcElwa(Device):
         if temp1error == True or modbusError == True or registerError == True:
             healthState = 2
 
-        self.__setHealthState__(healthState)
+        self.__sethealthstate__(healthState)
 
-    def __getRegisterMapping__(self):
+    def __getregistermapping__(self):
         datasets = {}
         datasets["day_counter"] = self.__createDataset__(1000, "avg")
         datasets["operation_mode"] = self.__createDataset__(1001, "avg")
@@ -274,22 +276,25 @@ class DeviceDcElwa(Device):
 # Entry Point     
 if __name__ == "__main__":
 
-    from mypvdevices.DcsConnection import DcsConnection
+    SCRIPT_DIR = os.path.dirname(os.path.realpath(os.path.join(os.getcwd(), os.path.expanduser(__file__))))
+    sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 
-    logging.basicConfig(format='%(asctime)s %(levelname)s [%(threadName)s]: %(message)s', level=logging.DEBUG)
+    from DcsConnection import DcsConnection
+
+    logging.basicConfig(format='%(asctime)s %(levelname)s [%(threadName)s]: %(message)s', level=logging.INFO)
 
     serial = "120100200505tes1"
-    cryptoKey = "ABABABABABABABAB"
+    cryptoKey = "ABABABABABABABABABABABABABABABAB"
     serial2 = "120100200505tes2"
-    cryptoKey2 = "ABABABABABABABAB"
+    cryptoKey2 = "ABABABABABABABABABABABABABABABAB"
     serial3 = "120100200505tes3"
-    cryptoKey3 = "ABABABABABABABAB"
+    cryptoKey3 = "ABABABABABABABABABABABABABABABAB"
     server = "my-pv.live"
 
     # try to read from valid device
     device = DeviceDcElwa(serial, 1)
     try:
-        device.__readRegisters__()
+        device.__readallregisters__()
         if(len(device.__registers__) == 24):
             print(color('SUCCESS: reading registers.', fore='green', style='bright'))
         else:
@@ -298,7 +303,7 @@ if __name__ == "__main__":
         print(color('ERROR: reading registers. ' + str(e), fore='red', style='bright'))
 
     try:
-        if device.__syncSettings__():
+        if device.__syncsettings__():
             print(color('SUCCESS: syncing settings.', fore='green', style='bright'))
         else:
             raise Exception("settings sync failed")
@@ -306,8 +311,8 @@ if __name__ == "__main__":
         print(color('ERROR: syncing settings. ' + str(e), fore='red', style='bright'))
 
     try:
-        device.__processRegisters__()
-        value = device.getDataset("dc_power")
+        device.__processregisters__()
+        value = device.getdataset("dc_power")
         if( value != None ):
             print(color('SUCCESS: processing registers.', fore='green', style='bright'))
         else:
@@ -316,7 +321,7 @@ if __name__ == "__main__":
         print(color('ERROR: processing registers. ' + str(e), fore='red', style='bright'))
 
     try:
-        value = device.getDataset("seppi")
+        value = device.getdataset("seppi")
         if( value == None ):
             print(color('SUCCESS: getting value of unkown registers.', fore='green', style='bright'))
         else:
@@ -325,13 +330,13 @@ if __name__ == "__main__":
         print(color('ERROR: getting value of unkown registers. ' + str(e), fore='red', style='bright'))
 
     time.sleep(2)
-    device.__processRegisters__()
+    device.__processregisters__()
     time.sleep(2)
 
-    device.__readRegisters__()
+    device.__readallregisters__()
     try:
-        device.__processRegisters__()
-        value = device.getLogValue("dc_power")
+        device.__processregisters__()
+        value = device.getlogvalue("dc_power")
         if( value != None ):
             print(color('SUCCESS: processing registers again.', fore='green', style='bright'))
         else:
@@ -340,26 +345,27 @@ if __name__ == "__main__":
         print(color('ERROR: processing registers again. ' + str(e), fore='red', style='bright'))
 
     
-    data = device.getData()
+    data = device.getdata()
     if(data != None and data != {}):
-        print(color('SUCCESS: getting getData.', fore='green', style='bright'))
+        print(color('SUCCESS: getting getdata.', fore='green', style='bright'))
     else:
-        print(color('ERROR: getting getData.', fore='red', style='bright'))
+        print(color('ERROR: getting getdata.', fore='red', style='bright'))
 
-    logData = device.getLogData()
+    logData = device.getlogdata()
     if(logData != None and logData != {}):
         print(color('SUCCESS: getting getLogData.', fore='green', style='bright'))
     else:
         print(color('ERROR: getting getLogData.', fore='red', style='bright'))
 
     key = "ww2target"
-    targetValue = 500
-    if(device.setSetupValue(key, targetValue)):
+    targetValue = 534
+    try:
+        device.setsetupvalue(key, targetValue)
         print(color('SUCCESS: sending setup value to device.', fore='green', style='bright'))
-    else:
+    except Exception as e:
         print(color('ERROR: sending setup value to device.', fore='red', style='bright'))
 
-    setup = device.getSetup()
+    setup = device.getsetup()
     if(setup[key] == targetValue):
         print(color('SUCCESS: Setting setup value.', fore='green', style='bright'))
     else:
@@ -370,15 +376,15 @@ if __name__ == "__main__":
     logging.getLogger().setLevel(logging.INFO)
     device = DeviceDcElwa(serial, 1)
     connection = DcsConnection(serial, cryptoKey, server, 50333)
-    device.addConnection(connection)
+    device.addconnection(connection)
     device.start()
 
     try:
         while True:
             print(color('[Device] test active. Press CTRL+C to stop', fore='blue', style='bright'))
-            device.showInfo()
-            device.showCommunicationErrors()
-            device.showCommunicationErrorsRate()
+            device.showinfo()
+            device.showcommunicationerrors()
+            device.showcommunicationerrorsrate()
             device.__supervise__()
             time.sleep(10)
     except KeyboardInterrupt as e:
@@ -391,16 +397,16 @@ if __name__ == "__main__":
     logging.getLogger().setLevel(logging.INFO)
     device = DeviceDcElwa(serial, 1)
     connection = DcsConnection(serial, cryptoKey, server, 50333)
-    device.addConnection(connection)
+    device.addconnection(connection)
     # device.setLogDataSendInterval(5)
 
     device2 = DeviceDcElwa(serial2, 2)
     connection2 = DcsConnection(serial2, cryptoKey2, server, 50333)
-    device2.addConnection(connection2)
+    device2.addconnection(connection2)
 
     device3 = DeviceDcElwa(serial3, 7)
     connection3 = DcsConnection(serial3, cryptoKey3, server, 50333)
-    device3.addConnection(connection3)
+    device3.addconnection(connection3)
 
     device.start()
     device2.start()
@@ -409,12 +415,12 @@ if __name__ == "__main__":
         while True:
             print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             # device.showInfo()
-            device.showCommunicationErrors()
-            device.showCommunicationErrorsRate()
-            device2.showCommunicationErrors()
-            device2.showCommunicationErrorsRate()
-            device3.showCommunicationErrors()
-            device3.showCommunicationErrorsRate()
+            device.showcommunicationerrors()
+            device.showcommunicationerrorsrate()
+            device2.showcommunicationerrors()
+            device2.showcommunicationerrorsrate()
+            device3.showcommunicationerrors()
+            device3.showcommunicationerrorsrate()
             time.sleep(10)
     except KeyboardInterrupt as e:
         print("[DCS-Connection] Stopping Test...")
