@@ -82,7 +82,7 @@ class ModbusConnection:     #Singleton
                 logging.error("[ModbusConnection] Unknown modbus connection error: " + str(e))
         return self.__modbusConnection__
 
-    def readRegisters(self, node, startAddress = 1000, registersToRead = 1):
+    def readregisters(self, node, startAddress = 1000, registersToRead = 1):
         with self.__mutex__:
             logging.debug("[ModbusConnection] Node " + str(node) + ": Reading " + str(registersToRead) +" registers starting with register "+ str(startAddress))
             try:
@@ -109,7 +109,7 @@ class ModbusConnection:     #Singleton
                     logging.warning("[ModbusConnection] Cannot read from node " + str(node) + ".")
         return registers
 
-    def writeRegister(self, node, registerId, value):
+    def writeregister(self, node, registerId, value):
         result = None
         with self.__mutex__:
             logging.debug("[ModbusConnection] Node " + str(node) + ": writing register " + str(registerId) +" with value "+ str(value))
@@ -131,6 +131,33 @@ class ModbusConnection:     #Singleton
                     logging.warning("[ModbusConnection] Cannot write to node " + str(node) + ".")
         return result
 
+    def readInputRegisters(self, node, startAddress = 1000, registersToRead = 1):
+        with self.__mutex__:
+            logging.debug("[ModbusConnection] Node " + str(node) + ": Reading " + str(registersToRead) +" input registers starting with register "+ str(startAddress))
+            try:
+                self.__connectionCounter__[node] += 1
+            except:
+                self.__connectionCounter__[node] = 1
+            registers = dict()
+            if self.__modbusClient__ != None:
+                if(self.__connectSocket__()):
+                    try:
+                        modbus_response = self.__modbusClient__.read_input_registers(startAddress, registersToRead, unit=node)
+                        if modbus_response.isError():
+                            raise Exception(str(modbus_response))
+
+                        logging.debug("[ModbusConnection] Node " + str(node) + ": Data: " + str(modbus_response.registers))
+                        for i in range(len(modbus_response.registers)):
+                            registers[startAddress + i] = modbus_response.registers[i]
+                    except Exception as e:
+                        logging.warning("[ModbusConnection] Modbus read error at node " + str(node) + ": " + str(e))
+                        self.__increaseModbusErrorCounter__(node)
+                        registers = None
+                        time.sleep(BUSRECOVERYTIME)
+                else:
+                    logging.warning("[ModbusConnection] Cannot read input registers from node " + str(node) + ".")
+        return registers
+
 # Entry Point     
 if __name__ == "__main__":
 
@@ -148,7 +175,7 @@ if __name__ == "__main__":
 
     # trying to read temperature from modbus module internal sensor
     internalTempRegisterNumber = 1021
-    register = ModbusConnection.instance().readRegisters(unitToTest, internalTempRegisterNumber, 1)
+    register = ModbusConnection.instance().readregisters(unitToTest, internalTempRegisterNumber, 1)
     errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
     errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
     if(register != None and register != {} and errors == 0 and errorrate == 0):
@@ -168,7 +195,7 @@ if __name__ == "__main__":
 
     # reading multiple registers
     ModbusConnection.instance().resetCounters(unitToTest)
-    register = ModbusConnection.instance().readRegisters(unitToTest, 1000, 24)
+    register = ModbusConnection.instance().readregisters(unitToTest, 1000, 24)
     errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
     errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
     if(register != None and register != {} and errors == 0 and errorrate == 0):
@@ -178,7 +205,7 @@ if __name__ == "__main__":
 
     # reading multiple registers again
     ModbusConnection.instance().resetCounters(unitToTest)
-    register = ModbusConnection.instance().readRegisters(unitToTest, 1000, 24)
+    register = ModbusConnection.instance().readregisters(unitToTest, 1000, 24)
     errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
     errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
     if(register != None and register != {} and errors == 0 and errorrate == 0):
@@ -187,7 +214,7 @@ if __name__ == "__main__":
         print(color('ERROR: Valid multiple register read twice.', fore='red', style='bright'))
 
     # reading an invalid node id
-    register = ModbusConnection.instance().readRegisters(99, 1000, 24)
+    register = ModbusConnection.instance().readregisters(99, 1000, 24)
     errors = ModbusConnection.instance().getModbusErrorCounter(99)
     if(register == None and errors == 1):
         print(color('SUCCESS: Invalid node read.', fore='green', style='bright'))
@@ -195,7 +222,7 @@ if __name__ == "__main__":
         print(color('ERROR: Invalid node read.', fore='red', style='bright'))
 
     # reading from broadcastr address
-    register = ModbusConnection.instance().readRegisters(0, 1000, 24)
+    register = ModbusConnection.instance().readregisters(0, 1000, 24)
     errors = ModbusConnection.instance().getModbusErrorCounter(0)
     if(register == None and errors == 1):
         print(color('ERROR: Node 0 (Broadcast) read.', fore='red', style='bright'))
@@ -204,7 +231,7 @@ if __name__ == "__main__":
 
     # reading of multiple invalid registers
     ModbusConnection.instance().resetCounters(unitToTest)
-    register = ModbusConnection.instance().readRegisters(unitToTest, 2000, 24)
+    register = ModbusConnection.instance().readregisters(unitToTest, 2000, 24)
     errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
     errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
     if(register == None and errors == 1 and errorrate == 1):
@@ -216,7 +243,7 @@ if __name__ == "__main__":
     ModbusConnection.instance().resetCounters(unitToTest)
     temp = 0
     for i in range(0, 50):
-        register = ModbusConnection.instance().readRegisters(unitToTest, 1000, 24)
+        register = ModbusConnection.instance().readregisters(unitToTest, 1000, 24)
         errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
         errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
         temp = ModbusConnection.instance().__connectionCounter__[unitToTest]
@@ -230,7 +257,7 @@ if __name__ == "__main__":
     register = 1023
     value = 1514
     try:
-        result = ModbusConnection.instance().writeRegister(unitToTest, register, value)
+        result = ModbusConnection.instance().writeregister(unitToTest, register, value)
         errors = ModbusConnection.instance().getModbusErrorCounter(unitToTest)
         errorrate =  ModbusConnection.instance().getModbusErrorRate(unitToTest)
         if(result != None and result.value == value and errors == 0 and errorrate == 0):
@@ -246,7 +273,7 @@ if __name__ == "__main__":
     value = 1514
     ModbusConnection.instance().resetCounters(node)
     try:
-        result = ModbusConnection.instance().writeRegister(node, register, value)
+        result = ModbusConnection.instance().writeregister(node, register, value)
         errors = ModbusConnection.instance().getModbusErrorCounter(node)
         errorrate =  ModbusConnection.instance().getModbusErrorRate(node)
         if(result == None and errors == 1 and errorrate == 1):
